@@ -125,7 +125,12 @@ public:
     Q_SIGNALS:
         /** Emitted when the initialization of the core components has been completed */
         void initializationCompleted();
-    
+        /**
+         * Emitted immediately before tearing down the session and UI.  Useful when performing any last minute
+         * preparations such as saving settings.
+         */
+        void aboutToShutdown();
+
 protected:
     ICore(QObject *parent = 0);
     static ICore *m_self;
