@@ -23,23 +23,29 @@
 
 namespace KDevelop {
 
-SpecializationStore::SpecializationStore() {
+SpecializationStore::SpecializationStore()
+{
 }
 
-SpecializationStore::~SpecializationStore() {
+SpecializationStore::~SpecializationStore()
+{
 }
 
-SpecializationStore& SpecializationStore::self() {
+SpecializationStore& SpecializationStore::self()
+{
   static SpecializationStore store;
   return store;
 }
 
-void SpecializationStore::set(DeclarationId declaration, IndexedInstantiationInformation specialization) {
+void SpecializationStore::set(const DeclarationId& declaration,
+                              const IndexedInstantiationInformation& specialization)
+{
   Q_ASSERT(specialization.index() >> 16);
   m_specializations[declaration] = specialization;
 }
 
-IndexedInstantiationInformation SpecializationStore::get(DeclarationId declaration) {
+IndexedInstantiationInformation SpecializationStore::get(const DeclarationId& declaration)
+{
   QHash<DeclarationId, IndexedInstantiationInformation>::const_iterator it = m_specializations.constFind(declaration);
   if(it != m_specializations.constEnd())
     return *it;
@@ -47,26 +53,29 @@ IndexedInstantiationInformation SpecializationStore::get(DeclarationId declarati
     return IndexedInstantiationInformation();
 }
 
-void SpecializationStore::clear(DeclarationId declaration) {
+void SpecializationStore::clear(const DeclarationId& declaration)
+{
   QHash<DeclarationId, IndexedInstantiationInformation>::iterator it = m_specializations.find(declaration);
   if(it != m_specializations.end())
     m_specializations.erase(it);
 }
 
-void SpecializationStore::clear() {
+void SpecializationStore::clear()
+{
   m_specializations.clear();
 }
 
-Declaration* SpecializationStore::applySpecialization(KDevelop::Declaration* declaration, KDevelop::TopDUContext* source, bool recursive) {
+Declaration* SpecializationStore::applySpecialization(Declaration* declaration, TopDUContext* source,
+                                                      bool recursive)
+{
   if(!declaration)
     return 0;
-  
+
   IndexedInstantiationInformation specialization = get(declaration->id());
   if(specialization.index())
     return declaration->specialize(specialization, source);
 
   if(declaration->context() && recursive) {
-    
     //Find a parent that has a specialization, and specialize this with the info and required depth
     int depth = 0;
     DUContext* ctx = declaration->context();
@@ -77,21 +86,23 @@ Declaration* SpecializationStore::applySpecialization(KDevelop::Declaration* dec
       ++depth;
       ctx = ctx->parentContext();
     }
-    
+
     if(specialization.index())
       return declaration->specialize(specialization, source, depth);
   }
-  
+
   return declaration;
 }
 
-DUContext* SpecializationStore::applySpecialization(KDevelop::DUContext* context, KDevelop::TopDUContext* source, bool recursive) {
+DUContext* SpecializationStore::applySpecialization(DUContext* context, TopDUContext* source,
+                                                    bool recursive)
+{
   if(!context)
     return 0;
-  
+
   if(Declaration* declaration = context->owner())
     return applySpecialization(declaration, source, recursive)->internalContext();
-  
+
   if(context->parentContext() && recursive) {
     //Find a parent that has a specialization, and specialize this with the info and required depth
     int depth = 0;
@@ -103,11 +114,11 @@ DUContext* SpecializationStore::applySpecialization(KDevelop::DUContext* context
       ++depth;
       ctx = ctx->parentContext();
     }
-    
+
     if(specialization.index())
       return context->specialize(specialization, source, depth);
   }
-  
+
   return context;
 }
 
