@@ -26,9 +26,14 @@ private:
 
 private slots:
     void initTestCase();
-    void testInitAndImport();
     void cleanupTestCase();
 
+    void init();
+    void cleanup();
+
+    void testInitAndImport();
+    void testLogFolder();
+
 private:
     CvsProxy* m_proxy;
 };
