@@ -342,6 +342,12 @@ NativeAppConfigType::NativeAppConfigType()
     factoryList.append( new NativeAppPageFactory() );
 }
 
+NativeAppConfigType::~NativeAppConfigType()
+{
+    qDeleteAll(factoryList);
+    factoryList.clear();
+}
+
 QString NativeAppConfigType::name() const
 {
     return i18n("Native Application");
@@ -408,7 +414,7 @@ QList<KDevelop::ProjectTargetItem*> targetsInFolder(KDevelop::ProjectFolderItem*
 QMenu* NativeAppConfigType::launcherSuggestions()
 {
     QMenu* ret = new QMenu;
-    ret->setTitle(tr("Project Executables"));
+    ret->setTitle(i18n("Project Executables"));
     
     KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
     QList<KDevelop::IProject*> projects = KDevelop::ICore::self()->projectController()->projects();
@@ -445,10 +451,10 @@ void NativeAppConfigType::suggestionTriggered()
         KDevelop::ILaunchConfiguration* config = KDevelop::ICore::self()->runController()->createLaunchConfiguration(this, launcher, p, pitem->text());
         KConfigGroup cfg = config->config();
         
-        QStringList splittedPath = model->pathFromIndex(pitem->index());
-//         QString path = KDevelop::joinWithEscaping(splittedPath,'/','\\');
-        cfg.writeEntry( ExecutePlugin::projectTargetEntry, splittedPath );
-        cfg.writeEntry( ExecutePlugin::dependencyEntry, KDevelop::qvariantToString( QVariantList() << splittedPath ) );
+        QStringList splitPath = model->pathFromIndex(pitem->index());
+//         QString path = KDevelop::joinWithEscaping(splitPath,'/','\\');
+        cfg.writeEntry( ExecutePlugin::projectTargetEntry, splitPath );
+        cfg.writeEntry( ExecutePlugin::dependencyEntry, KDevelop::qvariantToString( QVariantList() << splitPath ) );
         cfg.writeEntry( ExecutePlugin::dependencyActionEntry, "Build" );
         cfg.sync();
         
