@@ -500,6 +500,46 @@ void ProjectModelTest::testDeleteLots()
     modelTest = new ModelTest( model, this );
 }
 
+void ProjectModelTest::testItemsForUrl()
+{
+    QFETCH(KUrl, url);
+    QFETCH(ProjectBaseItem*, root);
+    QFETCH(int, matches);
+
+    model->appendRow(root);
+
+    QList< ProjectBaseItem* > items = model->itemsForUrl(url);
+    QCOMPARE(items.size(), matches);
+    foreach(ProjectBaseItem* item, items) {
+        QVERIFY(item->url().equals(url, KUrl::CompareWithoutTrailingSlash));
+    }
+
+    model->clear();
+}
+
+void ProjectModelTest::testItemsForUrl_data()
+{
+    QTest::addColumn<KUrl>("url");
+    QTest::addColumn<ProjectBaseItem*>("root");
+    QTest::addColumn<int>("matches");
+
+    {
+        ProjectFolderItem* root = new ProjectFolderItem(0, KUrl("file:////tmp/"));
+        ProjectFileItem* file = new ProjectFileItem(0, KUrl(root->url(), "a"), root);
+        QTest::newRow("find one") << file->url() << static_cast<ProjectBaseItem*>(root) << 1;
+    }
+
+    {
+        ProjectFolderItem* root = new ProjectFolderItem(0, KUrl("file:////tmp/"));
+        ProjectFolderItem* folder = new ProjectFolderItem(0, KUrl(root->url(), "a"), root);
+        ProjectFileItem* file = new ProjectFileItem(0, KUrl(folder->url(), "foo"), folder);
+        ProjectTargetItem* target = new ProjectTargetItem(0, "b", root);
+        ProjectFileItem* file2 = new ProjectFileItem(0, file->url(), target);
+        Q_UNUSED(file2);
+        QTest::newRow("find two") << file->url() << static_cast<ProjectBaseItem*>(root) << 2;
+    }
+}
+
 QTEST_KDEMAIN( ProjectModelTest, GUI)
 #include "projectmodeltest.moc"
 #include "moc_projectmodeltest.cpp"
