@@ -27,14 +27,20 @@
 #include <shell/core.h>
 #include <sublime/view.h>
 
+#include <ktexteditor/document.h>
+#include <ktexteditor/view.h>
 #include <KDebug>
-#include <QAction>
 
 #include <interfaces/contextmenuextension.h>
+#include <interfaces/idocumentcontroller.h>
+
 #include <language/interfaces/codecontext.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/duchainlock.h>
+#include <language/duchain/duchainutils.h>
 #include <documentation/documentationview.h>
+#include <KParts/MainWindow>
+#include <KActionCollection>
 
 using namespace KDevelop;
 
@@ -42,30 +48,41 @@ class DocumentationViewFactory: public KDevelop::IToolViewFactory
 {
     public:
         DocumentationViewFactory()
+            : mProvidersModel(0)
         {}
         
         virtual QWidget* create( QWidget *parent = 0 )
         {
-            return new DocumentationView( parent );
+            return new DocumentationView( parent, providers() );
         }
         
         virtual Qt::DockWidgetArea defaultPosition() { return Qt::RightDockWidgetArea; }
         virtual QString id() const { return "org.kdevelop.DocumentationView"; }
         
     private:
+        ProvidersModel* providers() {
+            if(!mProvidersModel)
+                mProvidersModel = new ProvidersModel;
+            
+            return mProvidersModel;
+        }
+        
+        ProvidersModel* mProvidersModel;
 };
 
 DocumentationController::DocumentationController(Core* core)
     : m_factory(new DocumentationViewFactory)
 {
-    Q_UNUSED( core );
-    m_showDocumentation = new QAction(i18n("Show Documentation"), this);
+    m_showDocumentation = core->uiController()->activeMainWindow()->actionCollection()->addAction("showDocumentation");
+    m_showDocumentation->setText(i18n("Show Documentation"));
+    m_showDocumentation->setShortcut(Qt::CTRL | Qt::ALT | Qt::Key_D);
+    m_showDocumentation->setIcon(KIcon("documentation"));
     connect(m_showDocumentation, SIGNAL(triggered(bool)), SLOT(doShowDocumentation()));
 }
 
 void DocumentationController::initialize()
 {
-    if(!(Core::self()->setupFlags() & Core::NoUi)) {
+    if(!documentationProviders().isEmpty() && !(Core::self()->setupFlags() & Core::NoUi)) {
         Core::self()->uiController()->addToolView( i18n("Documentation"), m_factory );
     }
 }
@@ -73,9 +90,28 @@ void DocumentationController::initialize()
 
 void KDevelop::DocumentationController::doShowDocumentation()
 {
-    KSharedPtr< IDocumentation > doc = m_showDocumentation->data().value<KSharedPtr<KDevelop::IDocumentation> >();
-    if(doc)
-        showDocumentation(doc);
+    IDocument* doc = ICore::self()->documentController()->activeDocument();
+    if(!doc)
+      return;
+    
+    KTextEditor::Document* textDoc = doc->textDocument();
+    if(!textDoc)
+      return;
+    
+    KTextEditor::View* view = textDoc->activeView();
+    if(!view)
+      return;
+    
+    KDevelop::DUChainReadLocker lock( DUChain::lock() );
+    
+    Declaration *dec = DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor( doc->url(), SimpleCursor(view->cursorPosition()) ) );
+    
+    if(dec) {
+        KSharedPtr< IDocumentation > documentation = documentationForDeclaration(dec);
+        if(documentation) {
+            showDocumentation(documentation);
+        }
+    }
 }
 
 
@@ -95,7 +131,6 @@ KDevelop::ContextMenuExtension KDevelop::DocumentationController::contextMenuExt
         
         KSharedPtr< IDocumentation > doc = documentationForDeclaration(ctx->declaration().data());
         if(doc) {
-            m_showDocumentation->setData(QVariant::fromValue(doc));
             menuExt.addAction(ContextMenuExtension::ExtensionGroup, m_showDocumentation);;
         }
     }
@@ -130,17 +165,23 @@ QList< IDocumentationProvider* > DocumentationController::documentationProviders
     foreach(IPlugin* p, pluginsProvider)
     {
         IDocumentationProviderProvider *docProvider=p->extension<IDocumentationProviderProvider>();
-        Q_ASSERT(docProvider);
+        if (!docProvider) {
+            kWarning() << "plugin" << p << "does not implement ProviderProvider extension, rerun kbuildsycoca4";
+            continue;
+        }
         ret.append(docProvider->providers());
     }
     
     foreach(IPlugin* p, plugins)
     {
         IDocumentationProvider *doc=p->extension<IDocumentationProvider>();
-        Q_ASSERT(doc);
+        if (!doc) {
+            kWarning() << "plugin" << p << "does not implement Provider extension, rerun kbuildsycoca4";
+            continue;
+        }
         ret.append(doc);
     }
-
+    
     return ret;
 }
 
