@@ -28,6 +28,7 @@ Boston, MA 02110-1301, USA.
 #include <QtGui/QDropEvent>
 #include <QtGui/QMenuBar>
 #include <QtCore/QMimeData>
+#include <QtDBus/QDBusConnection>
 
 #include <KDE/KApplication>
 #include <KDE/KActionCollection>
@@ -42,6 +43,7 @@ Boston, MA 02110-1301, USA.
 #include <kshortcutsdialog.h>
 #include <kxmlguifactory.h>
 #include <ktoggleaction.h>
+#include <KWindowSystem>
 
 #include <sublime/area.h>
 #include "shellextension.h"
@@ -59,10 +61,6 @@ Boston, MA 02110-1301, USA.
 #include <sublime/view.h>
 #include <sublime/document.h>
 #include <sublime/urldocument.h>
-#include <language/util/navigationtooltip.h>
-#include <language/duchain/duchainlock.h>
-#include <language/duchain/topducontext.h>
-#include <language/duchain/duchainutils.h>
 
 namespace KDevelop
 {
@@ -75,12 +73,15 @@ void MainWindow::applyMainWindowSettings(const KConfigGroup& config, bool force)
 
 QWidget* MainWindow::customButtonForAreaSwitcher ( Sublime::Area* area )
 {
-    return Core::self()->workingSetControllerInternal()->createSetManagerWidget(this, true, area);
+    return Core::self()->workingSetControllerInternal()->createSetManagerWidget(this, area);
 }
 
 MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
         : Sublime::MainWindow( parent, flags )
 {
+    QDBusConnection::sessionBus().registerObject( "/kdevelop/MainWindow",
+        this, QDBusConnection::ExportScriptableSlots );
+
     setAreaSwitcherCornerWidget(Core::self()->workingSetControllerInternal()->createSetManagerWidget(this));
     setAcceptDrops( true );
     KConfigGroup cg = KGlobal::config()->group( "UiSettings" );
@@ -117,14 +118,26 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
 
 MainWindow::~ MainWindow()
 {
+    Core::self()->uiControllerInternal()->mainWindowDeleted(this);
+
     if (memberList().count() == 1) {
         // We're closing down...
-        Core::self()->cleanup();
-        Core::self()->deleteLater();
+        Core::self()->shutdown();
     }
 
     delete d;
-    Core::self()->uiControllerInternal()->mainWindowDeleted(this);
+}
+
+void MainWindow::ensureVisible()
+{
+    if (isMinimized()) {
+        if (isMaximized()) {
+            showMaximized();
+        } else {
+            showNormal();
+        }
+    }
+    KWindowSystem::forceActiveWindow(winId());
 }
 
 QAction* MainWindow::createCustomElement(QWidget* parent, int index, const QDomElement& element)
@@ -149,20 +162,6 @@ QAction* MainWindow::createCustomElement(QWidget* parent, int index, const QDomE
     return KXMLGUIBuilder::createCustomElement(parent, index, element);
 }
 
-QWidget* MainWindow::createContainer(QWidget* parent, int index,
-    const QDomElement& element, QAction*& containerAction)
-{
-#if KDE_VERSION < KDE_MAKE_VERSION(4, 4, 0)
-    //for KDE < 4.4 we need to remove "Editor" toplevel menu - it will
-    //always be empty because our custom katepartui.rc is not used
-    const QString tagName = element.tagName().toLower();
-    if (tagName == QLatin1String("menu") &&
-            element.attribute(QLatin1String("name")).toUtf8() == "editor")
-        return 0;
-#endif
-    return KXMLGUIBuilder::createContainer(parent, index, element, containerAction);
-}
-
 void MainWindow::dragEnterEvent( QDragEnterEvent* ev )
 {
     if( ev->mimeData()->hasFormat( "text/uri-list" ) && ev->mimeData()->hasUrls() )
@@ -302,7 +301,6 @@ void MainWindow::initialize()
     foreach(IPlugin* plugin, Core::self()->pluginController()->loadedPlugins())
         d->addPlugin(plugin);
     
-    guiFactory()->addClient(Core::self()->debugControllerInternal());
     guiFactory()->addClient(Core::self()->sessionController());
     guiFactory()->addClient(Core::self()->sourceFormatterControllerInternal());
     // Needed to re-plug the actions from the sessioncontroller as xmlguiclients don't
@@ -313,14 +311,13 @@ void MainWindow::initialize()
     //Queued so we process it with some delay, to make sure the rest of the UI has already adapted
     connect(Core::self()->documentController(), SIGNAL(documentActivated(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
     connect(Core::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
+    connect(Core::self()->documentController(), SIGNAL(documentUrlChanged(KDevelop::IDocument*)), SLOT(updateCaption()), Qt::QueuedConnection);
     
     connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)), SLOT(updateCaption()));
     connect(Core::self()->projectController(), SIGNAL(projectClosed(KDevelop::IProject*)), SLOT(updateCaption()));
 
-    connect(Core::self()->sessionController()->activeSession(), SIGNAL(nameChanged(QString , QString)), SLOT(updateCaption()));
+    connect(Core::self()->sessionController()->activeSession(), SIGNAL(nameChanged(QString,QString)), SLOT(updateCaption()));
     
-    // Remove Handbook entry
-    actionCollection()->action( "help_contents" )->setVisible( false );
     updateCaption();
 }
 
@@ -374,14 +371,6 @@ void MainWindow::initializeStatusBar()
     d->setupStatusBar();
 }
 
-
-void MainWindow::setupAreaSelector()
-{
-    Sublime::MainWindow::setupAreaSelector();
-    d->setupAreaSelector();
-}
-
-
 void MainWindow::showErrorMessage(const QString& message, int timeout)
 {
     d->showErrorMessage(message, timeout);
@@ -393,32 +382,9 @@ void MainWindow::tabContextMenuRequested(Sublime::View* view, KMenu* menu)
     d->tabContextMenuRequested(view, menu);
 }
 
-void MainWindow::tabToolTipRequested(Sublime::View* view, QPoint point)
+void MainWindow::tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int tab)
 {
-    Q_UNUSED(point);
-    static QPointer<NavigationToolTip> toolTip;
-    
-    if(toolTip)
-        toolTip->close();
-    
-    DUChainReadLocker lock;
-    
-    Sublime::UrlDocument* urlDoc = dynamic_cast<Sublime::UrlDocument*>(view->document());
-    
-    if(urlDoc) {
-        TopDUContext* top = DUChainUtils::standardContextForUrl(urlDoc->url());
-                
-        if(top)
-        {
-            QWidget* navigationWidget = top->createNavigationWidget();
-            if( navigationWidget )
-            {
-                toolTip = new KDevelop::NavigationToolTip(this, QCursor::pos() + QPoint(20, 20), navigationWidget);
-                toolTip->resize( navigationWidget->sizeHint() + QSize(10, 10) );
-                ActiveToolTip::showToolTip(toolTip);
-            }
-        }
-    }
+    d->tabToolTipRequested(view, container, tab);
 }
 
 void MainWindow::dockBarContextMenuRequested(Qt::DockWidgetArea area, const QPoint& position)
