@@ -40,6 +40,7 @@ struct TestFile::TestFilePrivate {
     void updateReady(const IndexedString& _url, ReferencedTopDUContext _topContext)
     {
         Q_ASSERT(_url == url);
+        Q_UNUSED(_url);
         topContext = _topContext;
         ready = true;
     }
@@ -64,7 +65,9 @@ TestFile::TestFile (const QString& contents, const QString& fileExtension, TestP
     d->url = IndexedString(info.absoluteFilePath());
 
     d->project = project;
-    project->addToFileSet(d->url);
+    if (project) {
+        project->addToFileSet(d->url);
+    }
 }
 
 TestFile::~TestFile()
@@ -73,7 +76,9 @@ TestFile::~TestFile()
         DUChainWriteLocker lock;
         DUChain::self()->removeDocumentChain(d->topContext.data());
     }
-    d->project->removeFromFileSet(d->url);
+    if (d->project) {
+        d->project->removeFromFileSet(d->url);
+    }
     delete d;
 }
 
@@ -98,6 +103,11 @@ bool TestFile::waitForParsed(int timeout)
     return d->ready;
 }
 
+bool TestFile::isReady() const
+{
+    return d->ready;
+}
+
 ReferencedTopDUContext TestFile::topContext()
 {
     waitForParsed();
